#if !defined( PAL_INCLUDED )  /* Include this file only once */
#define PAL_INCLUDED
/*
*  Name:
*     pal.c

*  Purpose:
*     A wrapper for all PAL functions used by AST.

*  Description:
*     This file is a wrapper that includes all the source files from
*     the PAL and ERFA libraries.  This is done so that the function
*     names can be changed from the usual "palXxx" and "eraXxx" forms to
*     the private "astPalXxx" and "astIauXxx" forms. This renaming is
*     performed via the macros defined in the pal2ast.h and erfa2ast.h
*     include files. This is done in order to prevent clashes with any
*     external PAL or ERFA libraries with which an application is linked.
*
*     This file expects to find the publicly distributed and unmodified
*     PAL and ERFA source code in a pair of subdirectory called "pal" and
*     "erfa" within the current directory. The files within these
*     subdirectories do not need to be compiled - only this wrapper file
*     needs to be compiled.

*  Copyright:
*     Copyright (C) 2011 Science & Technology Facilities Council.
*     All Rights Reserved.

*  Licence:
*     This program is free software: you can redistribute it and/or
*     modify it under the terms of the GNU Lesser General Public
*     License as published by the Free Software Foundation, either
*     version 3 of the License, or (at your option) any later
*     version.
*     
*     This program is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU Lesser General Public License for more details.
*     
*     You should have received a copy of the GNU Lesser General
*     License along with this program.  If not, see
*     <http://www.gnu.org/licenses/>.

*  Authors:
*     DSB: D.S. Berry (JAC, Hawaii)

*  History:
*     16-FEB-2012 (DSB):
*        Original version.
*/

/* Include configuration results in order to get any definition for the
   EXTERNAL_PAL macro. This macro is set if the --with-external_pal
   option was set when AST was configured. */
#if HAVE_CONFIG_H
#include <config.h>
#endif

/* If an external PAL library is being used, we leave this file empty. */
#ifndef EXTERNAL_PAL

/* Rename all PAL functions so that references to "palXxx" in the files
   included below get translated to "astPalXxx". */
#include "pal2ast.h"

/* Rename all ERFA functions so that references to "eraXxx" in the files
   included below get translated to "astEraXxx". */

/* Include code from all PAL source files */
#include "pal/palAddet.c"
#include "pal/palAmpqk.c"
#include "pal/palCaldj.c"
#include "pal/palDat.c"
#include "pal/palDe2h.c"
#include "pal/palDeuler.c"
#include "pal/palDh2e.c"
#include "pal/palDjcal.c"
#include "pal/palDmat.c"
#include "pal/palDrange.c"
#include "pal/palDs2tp.c"
#include "pal/palDtp2s.c"
#include "pal/palDtps2c.c"
#include "pal/palDtt.c"
#include "pal/palEcmat.c"
#include "pal/palEqgal.c"
#include "pal/palEtrms.c"
#include "pal/palEvp.c"
#include "pal/palFk45z.c"
#include "pal/palFk524.c"
#include "pal/palFk54z.c"
#include "pal/palGaleq.c"
#include "pal/palGalsup.c"
#include "pal/palGeoc.c"
#include "pal/palMappa.c"
#include "pal/palMapqkz.c"
#include "pal/palOne2One.c"
#include "pal/palPrebn.c"
#include "pal/palPrec.c"
#include "pal/palPrenut.c"
#include "pal/palPvobs.c"
#include "pal/palRvgalc.c"
#include "pal/palRvlg.c"
#include "pal/palRvlsrd.c"
#include "pal/palRvlsrk.c"
#include "pal/palSubet.c"
#include "pal/palSupgal.c"

/* Include code from all ERFA source files */

#endif

#endif
